/***********************************************/
/* Examples Program For "CP-JR ARM7 LPC2368"   */
/* Target MCU  : Philips ARM7-LPC2368          */
/*       	   : X-TAL : 12.00 MHz             */
/*             : PLL Setup = MSEL(12),NSEL(1)  */
/* Keil Editor : uVision3 V3.53a               */
/* Compiler    : Keil Realview MDK V3.20	   */
/* Create By   : Eakachai Makarn(WWW.ETT.CO.TH)*/
/* Last Update : 12/November/2007              */
/* Function    : LCD-NOKIA6610 Demo Display    */
/*             : Used GPIO Pin Connect LCD     */
/***********************************************/
/***********************************************/
/* Pin Interface to LCD-NOKIA6610              */
/* P2.0 --> LCD_BL(Backlight Control)          */
/* P2.1 --> LCD_CS#					           */
/* P2.2 --> LCD_SCLK       		               */
/* P2.3 --> LCD_SDATA                          */
/* P2.4 --> LCD_RESET#     	   		       	   */
/***********************************************/

/* Include  Section */
#include "LPC23xx.H" 											// LPC2368 MPU Register
#include "font.h"												// Font Table Code

#include "bmp.h"												// Bitmap Graphic File
//#include "bug.h"												// Bitmap Graphic File

/* Philips(NXP):PCF8833 Controller Version */
#include "pcf8833.h"											// LCD-NOKIA6610 Philips(NXP):PCF8833 Controller
#include "pcf8833.c"

/* Epson:S1D15G00 Controller Version */
//#include "s1d15g00.h"											// LCD-NOKIA6610 Epson:S1D15G00 Controller
//#include "s1d15g00.c"

/* Main Program Start Here */
int main (void) 
{
  unsigned long j;
  int TempColor[11] = { WHITE, BLACK, RED, GREEN, BLUE, CYAN,
                        MAGENTA, YELLOW, BROWN, ORANGE, PINK };

  char *TempChar[11] = { "White  ", "Black  ", "Red    ", "Green  ", "Blue   ", "Cyan   ",
                         "Magenta", "Yellow ", "Brown  ", "Orange ", "Pink   " };

  /* Config P2[0..7] Interface LCD */
  PINSEL10  =  0;                         						// Disable ETM Interface
  PINSEL4  &= ~0x0000FFFF;										// P2[0..7] = GPIO
  FIO2DIR   =  0x000000FF;                						// P2[0..7] = Output
  FIO2MASK  =  0x00000000;

  LCD_BL_DIR();													// BL = Output
  LCD_CS_DIR();													// CS = Output
  LCD_SCLK_DIR();												// SCLK = Output
  LCD_SDATA_DIR();												// SDATA = Output
  LCD_RESET_DIR();												// RESET = Output
  LCD_SCLK_LOW();   											// Standby SCLK
  LCD_CS_HIGH();												// Disable CS
  LCD_SDATA_HIGH();												// Standby SDATA
  LCD_BL_HIGH();												// Black Light ON = 100%

  // Init LCD
  InitLcd(); 													// Initial LCD

  // Loop Test Display //
  while(1)
  {  
    // Test[1]  
    LCDClearScreen();											// Clear Screen	
    for (j = 0; j < 11; j++) 
    {    
      LCDSetRect(120, 10, 25, 120, FILL, TempColor[j]);  		// Draw Fill Box with Color
      LCDPutStr(TempChar[j], 5, 40, LARGE, YELLOW, BLACK);		// Label Name of Color    
      Delay(20000000); 											// Delay Page Display
    }

    // Test[2] 
    LCDClearScreen();											// Clear Screen		    
    LCDPutStr("Hello World", 60, 5, SMALL, WHITE, BLACK);  		// Draw String
    LCDPutStr("Hello World", 40, 5, MEDIUM, ORANGE, BLACK);
    LCDPutStr("Hello World", 20, 5, LARGE, PINK, BLACK);     
    LCDSetLine(120, 10, 120, 50, YELLOW); 						// Draw Line Create Rectangle
    LCDSetLine(120, 50, 80, 50, YELLOW);
    LCDSetLine(80, 50, 80, 10, YELLOW);
    LCDSetLine(80, 10, 120, 10, YELLOW);    
    LCDSetLine(120, 85, 80, 105, YELLOW);						// Draw Line Create X
    LCDSetLine(80, 85, 120, 105, YELLOW);    
    LCDSetCircle(65, 100, 10, RED);								// Draw Circle    
    LCDPutChar('E', 60, 98, SMALL, WHITE, BLACK);	 			// Draw Characters
    Delay(50000000); 											// Delay Page Display

    // Test[3]
    LCDClearScreen();	 										// Clear Screen
    LCDWrite130x130bmp();		   								// Display Graphic Bitmap 130x130
    LCDPutStr("This is Picture ", 115, 2, LARGE, BLACK, CYAN);
	Delay(50000000); 											// Delay Page Display
  }
}
/* End of Main */

